@@ -98,14 +98,14 @@ SignEncryptWidget::SignEncryptWidget(QWidget *parent, bool sigEncExclusive)
       mRecpRowCount(2),
       mIsExclusive(sigEncExclusive)
 {
-    QVBoxLayout *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     lay->setContentsMargins(0, 0, 0, 0);
 
     mModel->useKeyCache(true, KeyList::IncludeGroups);
 
     /* The signature selection */
-    QHBoxLayout *sigLay = new QHBoxLayout;
-    QGroupBox *sigGrp = new QGroupBox(i18n("Prove authenticity (sign)"));
+    auto sigLay = new QHBoxLayout;
+    auto sigGrp = new QGroupBox(i18n("Prove authenticity (sign)"));
     mSigChk = new QCheckBox(i18n("Sign as:"));
     mSigChk->setChecked(true);
 
@@ -124,8 +124,8 @@ SignEncryptWidget::SignEncryptWidget(QWidget *parent, bool sigEncExclusive)
     // Recipient selection
     mRecpLayout = new QGridLayout;
     mRecpLayout->setAlignment(Qt::AlignTop);
-    QVBoxLayout *encBoxLay = new QVBoxLayout;
-    QGroupBox *encBox = new QGroupBox(i18nc("@action", "Encrypt"));
+    auto encBoxLay = new QVBoxLayout;
+    auto encBox = new QGroupBox(i18nc("@action", "Encrypt"));
     encBox->setLayout(encBoxLay);
     encBox->setAlignment(Qt::AlignLeft);
 
@@ -142,15 +142,15 @@ SignEncryptWidget::SignEncryptWidget(QWidget *parent, bool sigEncExclusive)
     mEncOtherChk->setChecked(true);
     connect(mEncOtherChk, &QCheckBox::toggled, this,
         [this](bool toggled) {
-            for (CertificateLineEdit *edit : qAsConst(mRecpWidgets)) {
+            for (CertificateLineEdit *edit : std::as_const(mRecpWidgets)) {
                 edit->setEnabled(toggled);
             }
             updateOp();
         });
 
     // Scroll area for other keys
-    QWidget *recipientWidget = new QWidget;
-    QScrollArea *recipientScroll = new QScrollArea;
+    auto recipientWidget = new QWidget;
+    auto recipientScroll = new QScrollArea;
     recipientWidget->setLayout(mRecpLayout);
     recipientScroll->setWidget(recipientWidget);
     recipientScroll->setWidgetResizable(true);
@@ -223,7 +223,7 @@ SignEncryptWidget::SignEncryptWidget(QWidget *parent, bool sigEncExclusive)
 
 CertificateLineEdit *SignEncryptWidget::addRecipientWidget()
 {
-    CertificateLineEdit *certSel = new CertificateLineEdit(mModel, this,
+    auto certSel = new CertificateLineEdit(mModel, this,
                                                            new EncryptCertificateFilter(mCurrentProto));
     mRecpWidgets << certSel;
 
@@ -273,14 +273,14 @@ void SignEncryptWidget::dialogRequested(CertificateLineEdit *certificateLineEdit
         return;
     }
     if (!certificateLineEdit->group().isNull()) {
-        GroupDetailsDialog *dlg = new GroupDetailsDialog;
+        auto dlg = new GroupDetailsDialog;
         dlg->setAttribute(Qt::WA_DeleteOnClose);
         dlg->setGroup(certificateLineEdit->group());
         dlg->show();
         return;
     }
 
-    CertificateSelectionDialog *const dlg = new CertificateSelectionDialog(this);
+    auto const dlg = new CertificateSelectionDialog(this);
 
     dlg->setOptions(CertificateSelectionDialog::Options(
         CertificateSelectionDialog::MultiSelection |
@@ -318,16 +318,16 @@ void SignEncryptWidget::dialogRequested(CertificateLineEdit *certificateLineEdit
 
 void SignEncryptWidget::clearAddedRecipients()
 {
-    for (auto w: qAsConst(mUnknownWidgets)) {
+    for (auto w: std::as_const(mUnknownWidgets)) {
         mRecpLayout->removeWidget(w);
         delete w;
     }
 
-    for (auto &key: qAsConst(mAddedKeys)) {
+    for (auto &key: std::as_const(mAddedKeys)) {
         removeRecipient(key);
     }
 
-    for (auto &group: qAsConst(mAddedGroups)) {
+    for (auto &group: std::as_const(mAddedGroups)) {
         removeRecipient(group);
     }
 }
@@ -373,7 +373,7 @@ void SignEncryptWidget::addUnknownRecipient(const char *keyID)
 void SignEncryptWidget::recipientsChanged()
 {
     bool oneEmpty = false;
-    for (const CertificateLineEdit *w : qAsConst(mRecpWidgets)) {
+    for (const CertificateLineEdit *w : std::as_const(mRecpWidgets)) {
         if (w->key().isNull() && w->group().isNull()) {
             oneEmpty = true;
             break;
@@ -404,7 +404,7 @@ Key SignEncryptWidget::selfKey() const
 std::vector<Key> SignEncryptWidget::recipients() const
 {
     std::vector<Key> ret;
-    for (const CertificateLineEdit *w : qAsConst(mRecpWidgets)) {
+    for (const CertificateLineEdit *w : std::as_const(mRecpWidgets)) {
         if (!w->isEnabled()) {
             // If one is disabled, all are disabled.
             break;
@@ -477,7 +477,7 @@ void SignEncryptWidget::recpRemovalRequested(CertificateLineEdit *w)
         return;
     }
     int emptyEdits = 0;
-    for (const CertificateLineEdit *edit : qAsConst(mRecpWidgets)) {
+    for (const CertificateLineEdit *edit : std::as_const(mRecpWidgets)) {
         if (edit->isEmpty()) {
             emptyEdits++;
         }
@@ -506,7 +506,7 @@ void SignEncryptWidget::recpRemovalRequested(CertificateLineEdit *w)
 
 void SignEncryptWidget::removeRecipient(const GpgME::Key &key)
 {
-    for (CertificateLineEdit *edit: qAsConst(mRecpWidgets)) {
+    for (CertificateLineEdit *edit: std::as_const(mRecpWidgets)) {
         const auto editKey = edit->key();
         if (key.isNull() && editKey.isNull()) {
             recpRemovalRequested(edit);
@@ -523,7 +523,7 @@ void SignEncryptWidget::removeRecipient(const GpgME::Key &key)
 
 void SignEncryptWidget::removeRecipient(const KeyGroup &group)
 {
-    for (CertificateLineEdit *edit: qAsConst(mRecpWidgets)) {
+    for (CertificateLineEdit *edit: std::as_const(mRecpWidgets)) {
         const auto editGroup = edit->group();
         if (group.isNull() && editGroup.isNull()) {
             recpRemovalRequested(edit);
@@ -582,7 +582,7 @@ void SignEncryptWidget::setProtocol(GpgME::Protocol proto)
     mSigSelect->setKeyFilter(std::shared_ptr<KeyFilter>(new SignCertificateFilter(proto)));
     mSelfSelect->setKeyFilter(std::shared_ptr<KeyFilter>(new EncryptSelfCertificateFilter(proto)));
     const auto encFilter = std::shared_ptr<KeyFilter>(new EncryptCertificateFilter(proto));
-    for (CertificateLineEdit *edit : qAsConst(mRecpWidgets)) {
+    for (CertificateLineEdit *edit : std::as_const(mRecpWidgets)) {
         edit->setKeyFilter(encFilter);
     }
 
@@ -600,7 +600,7 @@ void SignEncryptWidget::setProtocol(GpgME::Protocol proto)
 
 bool SignEncryptWidget::validate()
 {
-    for (const auto edit: qAsConst(mRecpWidgets)) {
+    for (const auto edit: std::as_const(mRecpWidgets)) {
         if (!edit->isEmpty() && edit->key().isNull() && edit->group().isNull()) {
             KMessageBox::error(this, i18nc("%1 is user input that could not be found",
                         "Could not find a key for '%1'", edit->text().toHtmlEscaped()),
